@@ -11,8 +11,9 @@
 #'  For `step_embed`, this indicates the variables to be encoded
 #'  into a numeric format. See [recipes::selections()] for more
 #'  details. For the `tidy` method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
+#' @param role For model terms created by this step, what analysis
+#'  role should they be assigned?. By default, the function assumes
+#'  that the embedding variables created will be used as predictors in a model.
 #' @param outcome A call to `vars` to specify which variable is
 #'  used as the outcome in the neural network. Only
 #'  numeric and two-level factors are currently supported.
@@ -41,6 +42,7 @@
 #'  subsequent operations.
 #' @param trained A logical to indicate if the quantities for
 #'  preprocessing have been estimated.
+#' @param id A character string that is unique to this step to identify it.
 #' @return An updated version of `recipe` with the new step added
 #'  to the sequence of existing steps (if any). For the `tidy`
 #'  method, a tibble with columns `terms` (the selectors or
@@ -133,7 +135,7 @@
 step_embed <-
   function(recipe,
            ...,
-           role = NA,
+           role = "predictor",
            trained = FALSE,
            outcome = NULL,
            predictors = NULL,
@@ -142,7 +144,8 @@ step_embed <-
            options = embed_control(),
            mapping = NULL,
            history = NULL,
-           skip = FALSE) {
+           skip = FALSE,
+           id = rand_id("lencode_bayes")) {
     if (is.null(outcome))
       stop("Please list a variable in `outcome`", call. = FALSE)
     add_step(
@@ -158,23 +161,15 @@ step_embed <-
         options = options,
         mapping = mapping,
         history = history,
-        skip = skip
+        skip = skip,
+        id = id
       )
     )
   }
 
 step_embed_new <-
-  function(terms = NULL,
-           role = NA,
-           trained = FALSE,
-           outcome = NULL,
-           predictors = NULL,
-           num_terms = NULL,
-           hidden_units = NULL,
-           options = NULL,
-           mapping = NULL,
-           history = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, outcome, predictors, num_terms, hidden_units,
+           options, mapping, history, skip, id) {
     step(
       subclass = "embed",
       terms = terms,
@@ -187,7 +182,8 @@ step_embed_new <-
       predictors = predictors,
       mapping = mapping,
       history = history,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
@@ -216,14 +212,27 @@ prep.step_embed <- function(x, training, info = NULL, ...) {
       num = x$num_terms,
       h = x$hidden_units
     )
+  
+  # compute epochs actuually trained for
+  epochs <- min(res$history$params$epochs, length(res$history$metrics[[1]]))
 
-  x$mapping <- res$layer_values
-  x$history <- 
-    as_tibble(res$history$metrics) %>%
-    mutate(epochs = 1:res$history$params$epochs) %>%
-    gather(type, loss, -epochs)
-  x$trained <- TRUE
-  x
+  step_embed_new(
+    terms = x$terms,
+    role = x$role,
+    trained = TRUE,
+    outcome = x$outcome,
+    predictors = x$predictors,
+    num_terms = x$num_terms,
+    hidden_units = x$hidden_units,
+    options = x$options,
+    mapping = res$layer_values,
+    history = 
+      as_tibble(res$history$metrics) %>%
+      mutate(epochs = 1:epochs) %>%
+      gather(type, loss, -epochs),
+    skip = x$skip,
+    id = x$id
+  )
 }
 
 #' @importFrom keras keras_model_sequential layer_embedding layer_flatten
@@ -323,7 +332,8 @@ tf_coefs2 <- function(x, y, z, opt, num, lab, h, seeds = sample.int(10000, 4), .
       epochs = opt$epochs,
       validation_split = opt$validation_split,
       batch_size = opt$batch_size,
-      verbose = opt$verbose
+      verbose = opt$verbose,
+      callbacks = opt$callbacks
     )
 
   layer_values <- vector(mode = "list", length = p)
@@ -367,24 +377,24 @@ map_tf_coef2 <- function(dat, mapping, prefix) {
 #' @importFrom purrr map
 #' @importFrom dplyr bind_cols
 #' @export
-bake.step_embed <- function(object, newdata, ...) {
+bake.step_embed <- function(object, new_data, ...) {
   for (col in names(object$mapping)) {
-    tmp <- map_tf_coef2(newdata[, col], object$mapping[[col]], prefix = col)
-    newdata <- bind_cols(newdata, tmp)
+    tmp <- map_tf_coef2(new_data[, col], object$mapping[[col]], prefix = col)
+    new_data <- bind_cols(new_data, tmp)
     rm(tmp)
   }
-  newdata <- newdata[, !(names(newdata) %in% names(object$mapping))]
+  new_data <- new_data[, !(names(new_data) %in% names(object$mapping))]
   
-  newdata
+  new_data
 }
 
 #' @importFrom dplyr bind_rows 
 #' @importFrom tidyr gather
 #' @importFrom recipes is_trained
-#' @importFrom broom tidy
 #' @rdname step_embed
 #' @param x A `step_embed` object.
 #' @export
+#' @export tidy.step_embed
 tidy.step_embed <- function(x, ...) {
   if (is_trained(x)) {
     for(i in seq_along(x$mapping))
@@ -400,6 +410,7 @@ tidy.step_embed <- function(x, ...) {
       terms = term_names
     )
   }
+  res$id <- x$id
   res
 }
 
@@ -419,7 +430,7 @@ print.step_embed <-
 #' @export
 #' @rdname step_embed
 #' @param optimizer,loss,metrics Arguments to pass to [keras::compile()]
-#' @param epochs,validation_split,batch_size,verbose Arguments to pass to [keras::fit()]
+#' @param epochs,validation_split,batch_size,verbose,callbacks Arguments to pass to [keras::fit()]
 embed_control <- function(
   loss = "mse",
   metrics = NULL,
@@ -427,7 +438,8 @@ embed_control <- function(
   epochs = 20,
   validation_split = 0,
   batch_size = 32,
-  verbose = 0
+  verbose = 0,
+  callbacks = NULL
 ) {
   if(batch_size < 1)
     stop("`batch_size` should be a positive integer", call. = FALSE)
@@ -438,7 +450,7 @@ embed_control <- function(
   list(
     loss = loss, metrics = metrics, optimizer = optimizer, epochs = epochs, 
     validation_split = validation_split, batch_size = batch_size,
-    verbose = verbose)
+    verbose = verbose, callbacks = callbacks)
 }
 
 tf_options_check <- function(opt) {
